
# Slot: tree_root


indicator that this is the root class in tree structures

URI: [linkml:tree_root](https://w3id.org/linkml/tree_root)


## Domain and Range

[ClassDefinition](ClassDefinition.md) &#8594;  <sub>0..1</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
